@@ -6,7 +6,7 @@ use Cwd 'abs_path';
 use Exporter 'import';
 use Panda::Install::Payload;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.3';
 
 =head1 NAME
 
@@ -132,6 +132,10 @@ sub makemaker_args {
     delete $params{MODULE_INFO};
 
     $params{CCFLAGS} = "$Config{ccflags} $params{CCFLAGS}";
+
+    if (!$params{C} || !@{$params{C}} and !$params{OBJECT} || !@{$params{OBJECT}} and !$params{XS} || !scalar(keys %{$params{XS}})) {
+        delete $params{$_} for qw/C H OBJECT XS CCFLAGS LDFROM/;
+     }
     
     return %params;
 }
